@@ -5,6 +5,7 @@ import numpy as np
 import cv2
 
 from threading import local
+from wxbtool.data.variables import split_name
 from wxbtool.util.cmaps import cmaps, var2cmap
 
 
@@ -20,7 +21,7 @@ def imgdata():
 
 def colorize(data, out, cmap):
     data = data.reshape(32, 64)
-    data = (data - data.min()) / (data.max() - data.min())
+    data = (data - data.min() + 0.0001) / (data.max() - data.min() + 0.0001)
     data = (data * (data >= 0) * (data < 1) + (data >= 1)) * 255
     fliped = (data[::-1, :]).astype(np.uint8)
     return np.take(cmaps[cmap], fliped, axis=0, out=out)
@@ -33,4 +34,5 @@ def imsave(fileobj, data):
 
 
 def plot(var, fileobj, data):
-    imsave(fileobj, colorize(data, imgdata(), var2cmap[var]))
+    code, _ = split_name(var)
+    imsave(fileobj, colorize(data, imgdata(), var2cmap[code]))
